pub(crate) struct DelayWriter {
channel_info: ChannelInfo,
delay_line: Arc<RwLock<VecDeque<Block>>>,
upmixed_block: Arc<RwLock<Option<UpmixedBlock>>>,
max_delay_time: f64,
}Expand description
https://webaudio.github.io/web-audio-api/#delaywriter
…an object that has the same interface as an AudioNode, and that writes the input audio into the internal buffer of the DelayNode. It has the same input connections as the DelayNode it was created from.
Fields
channel_info: ChannelInfodelay_line: Arc<RwLock<VecDeque<Block>>>upmixed_block: Arc<RwLock<Option<UpmixedBlock>>>max_delay_time: f64Implementations
Sourceimpl DelayWriter
impl DelayWriter
pub(super) fn new( buffer: Arc<RwLock<VecDeque<Block>>>, upmixed_block: Arc<RwLock<Option<UpmixedBlock>>>, channel_info: ChannelInfo, max_delay_time: f64, ) -> Self
Sourcefn update_delay_line_capacity(&self, capacity: usize)
fn update_delay_line_capacity(&self, capacity: usize)
Updates the capacity of the delay line if it is currently zero.